# Democritus Netstrings

[![PyPI](https://img.shields.io/pypi/v/democritus-netstrings.svg)](https://pypi.python.org/pypi/democritus-netstrings)
[![Build Status](https://travis-ci.com/democritus-project/democritus-netstrings.svg?branch=master)](https://travis-ci.com/democritus-project/democritus-netstrings)
[![codecov](https://codecov.io/gh/democritus-project/democritus-netstrings/branch/master/graph/badge.svg?token=V0WOIXRGMM)](https://codecov.io/gh/democritus-project/democritus-netstrings)

Democritus functions<sup>[1]</sup> for working with Netstrings.

[1] Democritus functions are <i>simple, effective, modular, well-tested, and well-documented</i> Python functions.

## Usage

Coming soon...

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and Floyd Hightower's [Python project template](https://github.com/fhightower-templates/python-project-template).
